<?php

namespace Drupal\openstory\Plugin\views\style;

use Drupal\rest\Plugin\views\style\Serializer;
use Drupal\user\Entity\User;

/**
 * Create new serializer that will return the name of a user.
 *
 * @ingroup views_style_plugins
 *
 * @ViewsStyle(
 *   id = "openstory_entity_serializer",
 *   title = @Translation("OpenStory Entity Serializer"),
 *   help = @Translation("OpenStory entity serializer for the rest export"),
 *   display_types = {"data"}
 * )
 */
class OsEntitySerializer extends Serializer {

  /**
   * Get name of a user.
   */
  public function render() {
    $rows = [];
    foreach ($this->view->result as $row_index => $row) {
      $this->view->row_index = $row_index;
      $renderedRow = $this->view->rowPlugin->render($row);
      $currentRow = $renderedRow->toArray();
      if (is_array($currentRow)) {
        if (array_key_exists('uri', $currentRow)) {
          $currentUri = $currentRow['uri'][0]['value'];
          $currentRow['uri'][0]['value'] = file_create_url($currentUri);
        }
      }
      if (!empty($renderedRow->get('uid'))) {
        $uid = $renderedRow->get('uid')->getValue();
        if (!empty($uid[0]) && !empty($uid[0]['target_id'])) {
          $user = User::load($uid[0]['target_id']);
          if (!empty($user)) {
            $currentRow['username'] = $user->getAccountName();
          }
          else {
            $currentRow['username'] = 'Anonymous';
          }
        }
      }
      $rows[] = $currentRow;
    }

    unset($this->view->row_index);

    // Get the content type configured in the display or fallback to the
    // default.
    if ((empty($this->view->live_preview))) {
      $content_type = $this->displayHandler->getContentType();
    }
    else {
      $content_type = !empty($this->options['formats']) ? reset($this->options['formats']) : 'json';
    }

    return $this->serializer->serialize($rows, $content_type, ['views_style_plugin' => $this]);
  }

}
